@@ -64,7 +64,7 @@ class TableClient:
         """
         stm = """
             UNLOAD ('SELECT * FROM {schema}.{table}')
-            TO %(prefix)s iam_role %(role)s MANIFEST
+            TO %(prefix)s iam_role %(role)s MANIFEST ESCAPE
         """
         return self._db_client.execute(
             dynamic_query(
@@ -79,7 +79,7 @@ class TableClient:
     ) -> Cmd[None]:
         stm = """
             COPY {schema}.{table} FROM %(manifest_file)s
-            iam_role %(role)s MANIFEST
+            iam_role %(role)s MANIFEST ESCAPE
         """
         return self._db_client.execute(
             dynamic_query(
